package
module
Version:
v0.0.0-...-76db77a
Opens a new window with list of versions in this module.
Published: Apr 6, 2024
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
New instantiates and returns the required components used to handle a HTTP request
AllowList holds the necessary components of a Traefik plugin
ServeHTTP checks the leftmost ip in the XFF header to see if this ip is allowed
type Config struct {
Allow []string `json:"allow,omitempty" toml:"allow,omitempty" yaml:"allow,omitempty"`
}
CreateConfig creates and initializes the plugin configuration.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.